@@ -10,7 +10,7 @@ LInorm = function(x, k, conf.level=0.95) {
   if (!missing(k)) {
     logk = log(k)
   } else {
-    logk = n0/2*log(1 + qf(conf.level, 1, n0 - 2)/(n0 - 2))
+    logk = n0/2*log(1 + 2*qf(conf.level, 2, n0 - 2)/(n0 - 2))
     logk = min(logk, log(2/(1 - conf.level)))
   }
   
